@@ -22,7 +22,7 @@ import json
 from netbluemind.python import serder
 from netbluemind.python.client import BaseEndpoint
 
-IAddressBook_VERSION = "4.1.62024"
+IAddressBook_VERSION = "4.1.62110"
 
 class IAddressBook(BaseEndpoint):
     def __init__(self, apiKey, url ,containerUid ):
@@ -259,6 +259,16 @@ class IAddressBook(BaseEndpoint):
         from netbluemind.core.container.api.Count import Count
         from netbluemind.core.container.api.Count import __CountSerDer__
         return self.handleResult__(__CountSerDer__(), response)
+    def touch (self, uid ):
+        postUri = "/{uid}/_touch";
+        __data__ = None
+        __encoded__ = None
+        __data__ = serder.STRING.encode(uid)
+        __encoded__ = json.dumps(__data__)
+        queryParams = {   };
+
+        response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IAddressBook_VERSION}, data = __encoded__);
+        return self.handleResult__(None, response)
     def sortedIds (self, sorted ):
         postUri = "/_sorted";
         __data__ = None
