@@ -22,7 +22,7 @@ import json
 from netbluemind.python import serder
 from netbluemind.python.client import BaseEndpoint
 
-IMailboxMgmt_VERSION = "4.1.62024"
+IMailboxMgmt_VERSION = "4.1.62110"
 
 class IMailboxMgmt(BaseEndpoint):
     def __init__(self, apiKey, url ,domainUid ):
@@ -32,6 +32,16 @@ class IMailboxMgmt(BaseEndpoint):
         self.domainUid_ = domainUid
         self.base = self.base.replace('{domainUid}',domainUid)
 
+    def getLiteStats (self):
+        postUri = "/liteStats";
+        __data__ = None
+        __encoded__ = None
+        queryParams = {  };
+
+        response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IMailboxMgmt_VERSION}, data = __encoded__);
+        from netbluemind.mailbox.api.SimpleShardStats import SimpleShardStats
+        from netbluemind.mailbox.api.SimpleShardStats import __SimpleShardStatsSerDer__
+        return self.handleResult__(serder.ListSerDer(__SimpleShardStatsSerDer__()), response)
     def getShardsStats (self):
         postUri = "/shardsStats";
         __data__ = None
