@@ -26,6 +26,7 @@ class MailFilterVacation :
         self.start = None
         self.end = None
         self.text = None
+        self.textHtml = None
         self.subject = None
         pass
 
@@ -50,6 +51,8 @@ class __MailFilterVacationSerDer__:
         instance.end = serder.DATE.parse(endValue)
         textValue = value['text']
         instance.text = serder.STRING.parse(textValue)
+        textHtmlValue = value['textHtml']
+        instance.textHtml = serder.STRING.parse(textHtmlValue)
         subjectValue = value['subject']
         instance.subject = serder.STRING.parse(subjectValue)
         return instance
@@ -71,6 +74,8 @@ class __MailFilterVacationSerDer__:
         instance["end"] = serder.DATE.encode(endValue)
         textValue = value.text
         instance["text"] = serder.STRING.encode(textValue)
+        textHtmlValue = value.textHtml
+        instance["textHtml"] = serder.STRING.encode(textHtmlValue)
         subjectValue = value.subject
         instance["subject"] = serder.STRING.encode(subjectValue)
         return instance
