@@ -34,6 +34,7 @@ class User (DirBaseValue):
         self.routing = None
         self.accountType = None
         self.quota = None
+        self.mailboxCopyGuid = None
         self.properties = None
         pass
 
@@ -75,6 +76,8 @@ class __UserSerDer__:
         instance.accountType = __BaseDirEntryAccountTypeSerDer__().parse(accountTypeValue)
         quotaValue = value['quota']
         instance.quota = serder.INT.parse(quotaValue)
+        mailboxCopyGuidValue = value['mailboxCopyGuid']
+        instance.mailboxCopyGuid = serder.STRING.parse(mailboxCopyGuidValue)
         propertiesValue = value['properties']
         instance.properties = serder.MapSerDer(serder.STRING).parse(propertiesValue)
         return instance
@@ -113,6 +116,8 @@ class __UserSerDer__:
         instance["accountType"] = __BaseDirEntryAccountTypeSerDer__().encode(accountTypeValue)
         quotaValue = value.quota
         instance["quota"] = serder.INT.encode(quotaValue)
+        mailboxCopyGuidValue = value.mailboxCopyGuid
+        instance["mailboxCopyGuid"] = serder.STRING.encode(mailboxCopyGuidValue)
         propertiesValue = value.properties
         instance["properties"] = serder.MapSerDer(serder.STRING).encode(propertiesValue)
         return instance
